// Chess diagram drawing JavaScript
// Written by Milan Velimirovic, e-mail: mivel@sezampro.yu

//=================================================
// Draw the diagram
//	str = MatPlus type shortened Forsyth notation (English)

function diagx(str)
{
	var res = "<table border=1><tr><td nowrap>\r\n";
	var j = str.length;
	var empty = 0;
	var ch, e;
	var c=0;
	var c1;
	var dlm=0;
	var alt = ' alt="' + str + '"';
	var rest = 64;
	var br = 0;
	var err = 0;
	var neutral="";
	var rot="";
	for (i=0; i<j+1; i++) {
		ch = str.charAt(i);
		if (ch>='0' && ch<='9') empty = empty * 10 + parseInt(ch);
		else if (ch=='!') neutral='N';
		else if (ch=='*') {
			if (rot=="") rot='1';
			else if (rot=='1') rot='2';
			else if (rot=='2') rot='3';
		}
		else {
			if (i>=j) empty=rest;
			while (empty>0) {
				e = 8-br;
				if (e>empty) e=empty;
				res += '<IMG SRC="';
				if (e>1) res += e;
				res += c + '.GIF"' + alt + '>';
				alt="";
				empty -= e;
				br = (br+e) & 7;
				c = (c+e+1) & 1;
				if (br==0 && i<60) res += "<br>\r\n";
				else c ^= 1;
				rest -= e;
			}
			if (i<j) {
				res += '<IMG SRC="';
				switch (ch) {
				case 'K': case 'Q': case 'R': case 'B': case 'S': case 'P': 
					res += neutral + ch + c + rot;
					break;
				case 'k': case 'q': case 'r': case 'b': case 's': case 'p': 
					if (neutral=="") c1 = c+2;
					else c1=c;
					res += neutral + ch.toUpperCase() + c1 + rot;
					break;
				default:
					res = res + "ER";
					err=1;
				}
				res = res + '.GIF"' + alt + '>';
				alt="";
				br = ++br & 7;
				if (br==0 && i<60) res += "<br>\r\n";
				else c ^= 1;
				rest--; 
				rot="";
				neutral="";
			}
		}
	}
	res += "</td></tr></table>\r\n";
	if (err==1) alert("Invalid diagram");
	return res;
}



//=================================================
// Show complete problem

function problem(aut, sou, pos, cond, extra, sum, sol)
{
	var res = "<tr><td width=200 align=center><b>";
	res += aut +"</b><br><i><small>" + sou + "</small></i><br>\r\n";
	res += diag(pos);
	res += "<table width=170><tr valign=top>\r\n<td><small>" + cond + "</small></td>\r\n<td align=center><small>" + extra + "</small></td>\r\n<td align=right><small>" + sum + "</small></td></tr></table>\r\n";
	res += "</td>\r\n";
	res += "<td width=400 valign=middle><small>" + sol + "</small></td>\r\n</tr>\r\n";	
	return res;
}


//=================================================
// Function problem3
//	shows 3 problems in row
// 3 parms with keywords:
//	A=author$ O=source$ P=pos$ C=Cond$ E=extra$ T=sum$ S=solution$
//	and also: N=name$ H=href$

function getVar(s, kw)
{
	var i = s.indexOf(kw, -1);
	if (i==-1) return " "; 
	var l=s.length;
	i+=2;
	var res = "";
	var b = s.charAt(i);
	while (b != '$' && i<l) {
		res += b;
		i++;
		b = s.charAt(i);
	}
	return res;
}

function problem3Author(s)
{
	var res = "<td align=center><b>";
	var n = getVar(s, "N=");
	var h = getVar(s, "H=");
	if (n!=" ") {
		res += '<a name="' + n + '">';
		if (h!=" ") res += '<a href="' + h + '">' + n + "</a> ";
	}
	res += getVar(s, "A=") + "</b><br><small><i>";
	res += getVar(s, "O=") + "</i></small></td>\r\n";
	return res;
}

function problem3Pos(s)
{
	var res = "<td align=center>" + diag(getVar(s, "P="));
	res += "<table width=170><tr valign=top>";
	res += "<td><small>" + getVar(s, "C=") + "</small></td>";
	res += "<td align=center><small>" + getVar(s, "E=") + "</small></td>";
	res += "<td align=right><small>" + getVar(s, "T=") + "</small></td></tr></table>\r\n";
	res += "</td>\r\n";
	return res;
}

function problem3Sol(s)
{
	var res = "<td width=190><small>";
	var r = getVar(s, "S=", -1);
	if (r==" ") r = "&nbsp;";
	res += r + "</small></td>\r\n";
	return res;
}
	
function problem3(s1, s2, s3)
{
	var res = "<table width=100%><tr valign=bottom>\r\n";
	res += problem3Author(s1);
	res += problem3Author(s2);
	res += problem3Author(s3);
	res += "</tr><tr valign=top>\r\n";
	res += problem3Pos(s1);
	res += problem3Pos(s2);
	res += problem3Pos(s3);
	var kw = "S=";
	var i = s1.indexOf(kw, -1);
	if (i==-1) i = s2.indexOf(kw, -1);
	if (i==-1) i = s3.indexOf(kw, -1);
	if (i>=0) {
		res += "</tr><tr valign=top>";
		res += problem3Sol(s1);
		res += problem3Sol(s2);
		res += problem3Sol(s3);
	}
	res += "</tr></table>\r\n\r\n";
	return res;
}

